@@ -4,7 +4,7 @@
 
 use deno_core::error::AnyError;
 use deno_core::include_js_files;
-use deno_core::op_sync;
+use deno_core::op;
 use deno_core::Extension;
 use deno_core::OpState;
 use rusqlite::params;
@@ -26,16 +26,13 @@ pub fn init(origin_storage_dir: Option<PathBuf>) -> Extension {
       "01_webstorage.js",
     ))
     .ops(vec![
-      ("op_webstorage_length", op_sync(op_webstorage_length)),
-      ("op_webstorage_key", op_sync(op_webstorage_key)),
-      ("op_webstorage_set", op_sync(op_webstorage_set)),
-      ("op_webstorage_get", op_sync(op_webstorage_get)),
-      ("op_webstorage_remove", op_sync(op_webstorage_remove)),
-      ("op_webstorage_clear", op_sync(op_webstorage_clear)),
-      (
-        "op_webstorage_iterate_keys",
-        op_sync(op_webstorage_iterate_keys),
-      ),
+      op_webstorage_length::decl(),
+      op_webstorage_key::decl(),
+      op_webstorage_set::decl(),
+      op_webstorage_get::decl(),
+      op_webstorage_remove::decl(),
+      op_webstorage_clear::decl(),
+      op_webstorage_iterate_keys::decl(),
     ])
     .state(move |state| {
       if let Some(origin_storage_dir) = &origin_storage_dir {
@@ -46,10 +43,6 @@ pub fn init(origin_storage_dir: Option<PathBuf>) -> Extension {
     .build()
 }
 
-pub fn get_declaration() -> PathBuf {
-  PathBuf::from(env!("CARGO_MANIFEST_DIR")).join("lib.deno_webstorage.d.ts")
-}
-
 struct LocalStorage(Connection);
 struct SessionStorage(Connection);
 
@@ -107,10 +100,10 @@ fn get_webstorage(
   Ok(conn)
 }
 
+#[op]
 pub fn op_webstorage_length(
   state: &mut OpState,
   persistent: bool,
-  _: (),
 ) -> Result<u32, AnyError> {
   let conn = get_webstorage(state, persistent)?;
 
@@ -120,6 +113,7 @@ pub fn op_webstorage_length(
   Ok(length)
 }
 
+#[op]
 pub fn op_webstorage_key(
   state: &mut OpState,
   index: u32,
@@ -144,6 +138,7 @@ pub struct SetArgs {
   key_value: String,
 }
 
+#[op]
 pub fn op_webstorage_set(
   state: &mut OpState,
   args: SetArgs,
@@ -171,6 +166,7 @@ pub fn op_webstorage_set(
   Ok(())
 }
 
+#[op]
 pub fn op_webstorage_get(
   state: &mut OpState,
   key_name: String,
@@ -186,6 +182,7 @@ pub fn op_webstorage_get(
   Ok(val)
 }
 
+#[op]
 pub fn op_webstorage_remove(
   state: &mut OpState,
   key_name: String,
@@ -199,10 +196,10 @@ pub fn op_webstorage_remove(
   Ok(())
 }
 
+#[op]
 pub fn op_webstorage_clear(
   state: &mut OpState,
   persistent: bool,
-  _: (),
 ) -> Result<(), AnyError> {
   let conn = get_webstorage(state, persistent)?;
 
@@ -212,10 +209,10 @@ pub fn op_webstorage_clear(
   Ok(())
 }
 
+#[op]
 pub fn op_webstorage_iterate_keys(
   state: &mut OpState,
   persistent: bool,
-  _: (),
 ) -> Result<Vec<String>, AnyError> {
   let conn = get_webstorage(state, persistent)?;
 
